@@ -14,7 +14,7 @@ from forms import ImageForm, FileForm
 from sorl.thumbnail import get_thumbnail
 
 
-UPLOAD_PATH = getattr(settings, 'IMPERAVI_UPLOAD_PATH', 'imperavi')
+UPLOAD_PATH = getattr(settings, 'IMPERAVI_UPLOAD_PATH', 'imperavi/')
 
 
 @require_POST
@@ -31,7 +31,7 @@ def upload_image(request, upload_path=None):
         hashed_name = '{0}{1}'.format(m.hexdigest(), extension)
         image_path = default_storage.save(os.path.join(upload_path or UPLOAD_PATH, hashed_name), image)
         image_url = default_storage.url(image_path)
-        return HttpResponse('<img src="%s">' % image_url)
+        return HttpResponse(json.dumps({'filelink': image_url}))
     return HttpResponseForbidden()
 
 
@@ -39,14 +39,16 @@ def upload_image(request, upload_path=None):
 def uploaded_images_json(request, upload_path=None):
     upload_path = upload_path or UPLOAD_PATH
     results = list()
-    for (path, dirs, files) in os.walk(os.path.join(settings.MEDIA_ROOT, upload_path)):
-        for image in files:
-            image_path = '{0}/{1}'.format(path, image)
-            if imghdr.what(image_path):
+    path = os.path.join(settings.MEDIA_ROOT, upload_path)
+    if os.path.isdir(path):
+        for image in os.listdir(path):
+            image_path = '{0}{1}'.format(path, image)
+            if not os.path.isdir(image_path) and imghdr.what(image_path):
                 thumb = get_thumbnail(image_path, '100x74', crop='center')
-                image_url = default_storage.url(image_path)
+                image_url = os.path.join(settings.MEDIA_URL, upload_path, image)
                 results.append({'thumb': thumb.url, 'image': image_url})
-    return HttpResponse(json.dumps(results))
+        return HttpResponse(json.dumps(results))
+    return HttpResponse('{}')
 
 
 @require_POST
@@ -61,5 +63,5 @@ def upload_file(request, upload_path=None, upload_link=None):
         image_url = default_storage.url(image_path)
         if upload_link:
             return HttpResponse(image_url)
-        return HttpResponse('<a href="%s">%s</a>' % (image_url, uploaded_file.name))
+        return HttpResponse(json.dumps({'filelink': image_url, 'filename': uploaded_file.name}))
     return HttpResponseForbidden()
