@@ -7,6 +7,8 @@ from django.utils.encoding import force_unicode
 from django.core.urlresolvers import reverse
 from django.conf import settings
 
+from views import UPLOAD_PATH
+
 
 IMPERAVI_SETTINGS = getattr(settings, 'IMPERAVI_CUSTOM_SETTINGS', {})
 
@@ -14,8 +16,8 @@ IMPERAVI_SETTINGS = getattr(settings, 'IMPERAVI_CUSTOM_SETTINGS', {})
 class ImperaviWidget(Textarea):
 
     def __init__(self, *args, **kwargs):
+        self.upload_path = kwargs.pop('upload_path', UPLOAD_PATH)
         self.imperavi_settings = IMPERAVI_SETTINGS
-        self.upload_path = kwargs.pop('upload_path', 'imperavi')
         super(ImperaviWidget, self).__init__(*args, **kwargs)
 
     def render(self, name, value, attrs=None):
@@ -36,10 +38,12 @@ class ImperaviWidget(Textarea):
             </div>
             <script>
                 $(document).ready(
-                function() {
-                    $("#%(id)s").parent().siblings('label').css('float', 'none');
-                    $("#%(id)s").redactor(%(imperavi_settings)s);
-                });
+                    function() {
+                        $("#%(id)s").parent().siblings('label').css('float', 'none');
+                        $("#%(id)s").height(300);
+                        $("#%(id)s").redactor(%(imperavi_settings)s);
+                    }
+                );
             </script>
             """ % {
                 'attrs': flatatt(final_attrs),
